@@ -1682,6 +1682,9 @@ ews_download_full_gal (EBookBackendEws *cbews,
 	gchar *full_url, *oab_url, *cache_file = NULL;
 	const gchar *cache_dir;
 	gchar *comp_cache_file = NULL, *uncompress_file = NULL;
+	CamelEwsSettings *settings;
+
+	settings = book_backend_ews_get_collection_settings (cbews);
 
 	/* oab url with oab.xml removed from the suffix */
 	oab_url = g_strndup (priv->oab_url, strlen (priv->oab_url) - 7);
@@ -1689,7 +1692,10 @@ ews_download_full_gal (EBookBackendEws *cbews,
 	cache_dir = e_book_backend_get_cache_dir (E_BOOK_BACKEND (cbews));
 	comp_cache_file = g_build_filename (cache_dir, full->filename, NULL);
 
-	oab_cnc = e_ews_connection_new (full_url, priv->username, priv->password, NULL, NULL, NULL);
+	oab_cnc = e_ews_connection_new (full_url, priv->username, priv->password,
+		camel_network_settings_get_auth_mechanism (CAMEL_NETWORK_SETTINGS (settings)),
+		camel_ews_settings_get_timeout (settings),
+		NULL, NULL, NULL);
 	if (!e_ews_connection_download_oal_file_sync (
 		oab_cnc, comp_cache_file, NULL, NULL, cancellable, error))
 		goto exit;
@@ -1837,11 +1843,16 @@ ebews_start_gal_sync (gpointer data)
 	GSList *full_l = NULL;
 	gboolean ret = TRUE;
 	gchar *uncompressed_filename = NULL;
+	CamelEwsSettings *settings;
 
 	cbews = (EBookBackendEws *) data;
+	settings = book_backend_ews_get_collection_settings (cbews);
 	priv = cbews->priv;
 
-	oab_cnc = e_ews_connection_new (priv->oab_url, priv->username, priv->password, NULL, NULL, NULL);
+	oab_cnc = e_ews_connection_new (priv->oab_url, priv->username, priv->password,
+		camel_network_settings_get_auth_mechanism (CAMEL_NETWORK_SETTINGS (settings)),
+		camel_ews_settings_get_timeout (settings),
+		NULL, NULL, NULL);
 
 	d(printf ("Ewsgal: Fetching oal full details file \n");)
 
@@ -2041,23 +2052,6 @@ ebews_get_vcards_list (GSList *new_items,
 	g_slist_free (new_items);
 }
 
-static void
-ews_mb_free (EwsMailbox *mb)
-{
-	if (mb) {
-		g_free (mb->name);
-		g_free (mb->email);
-
-		if (mb->item_id) {
-			g_free (mb->item_id->id);
-			g_free (mb->item_id->change_key);
-			g_free (mb->item_id);
-		}
-
-		g_free (mb);
-	}
-}
-
 static void
 ebews_store_distribution_list_items (EBookBackendEws *ebews,
                                      const EwsId *id,
@@ -2098,7 +2092,7 @@ ebews_store_distribution_list_items (EBookBackendEws *ebews,
 			e_vcard_attribute_add_value (attr, mb->email);
 
 		e_vcard_add_attribute (E_VCARD (contact), attr);
-		ews_mb_free (mb);
+		e_ews_mailbox_free (mb);
 	}
 
 	g_slist_free (members);
@@ -2146,7 +2140,7 @@ ebews_vcards_append_dl (const EwsId *id,
 			e_vcard_attribute_add_value (attr, mb->email);
 
 		e_vcard_add_attribute (E_VCARD (contact), attr);
-		ews_mb_free (mb);
+		e_ews_mailbox_free (mb);
 	}
 	vcard_string = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 	*vcards = g_slist_append (*vcards, g_strdup(vcard_string));
@@ -2603,9 +2597,7 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 
 		e_data_book_view_notify_update (book_view, contact);
 
-		g_free (mb->email);
-		g_free (mb->name);
-		g_free (mb);
+		e_ews_mailbox_free (mb);
 		e_ews_free_resolve_contact (rc);
 		g_object_unref (contact);
 	}
@@ -2959,7 +2951,10 @@ book_backend_ews_try_password_sync (ESourceAuthenticator *authenticator,
 	user = camel_network_settings_dup_user (network_settings);
 
 	connection = e_ews_connection_new (
-		hosturl, user, password->str, NULL, NULL, error);
+		hosturl, user, password->str,
+		camel_network_settings_get_auth_mechanism (network_settings),
+		camel_ews_settings_get_timeout (ews_settings),
+		NULL, NULL, error);
 
 	if (connection == NULL) {
 		result = E_SOURCE_AUTHENTICATION_ERROR;
