@@ -60,13 +60,11 @@
 #define FINFO_REFRESH_INTERVAL 60
 
 struct _CamelEwsStorePrivate {
-
 	time_t last_refresh_time;
 	GMutex *get_finfo_lock;
 	EEwsConnection *cnc;
 };
 
-extern CamelServiceAuthType camel_ews_password_authtype; /*for the query_auth_types function */
 static gboolean	ews_store_construct	(CamelService *service, CamelSession *session,
 					 CamelProvider *provider, GError **error);
 
@@ -194,21 +192,6 @@ ews_store_construct (CamelService *service,
 	return TRUE;
 }
 
-static guint
-ews_hash_folder_name (gconstpointer key)
-{
-	return g_str_hash (key);
-}
-
-static gint
-ews_compare_folder_name (gconstpointer a,
-                         gconstpointer b)
-{
-	gconstpointer aname = a, bname = b;
-
-	return g_str_equal (aname, bname);
-}
-
 static void
 ews_update_folder_hierarchy (CamelEwsStore *ews_store,
                              gchar *sync_state,
@@ -230,6 +213,19 @@ ews_update_folder_hierarchy (CamelEwsStore *ews_store,
 	g_free (sync_state);
 }
 
+static void
+ews_store_update_cnc_timeout_cb (CamelEwsSettings *settings,
+				 GParamSpec *spec,
+				 CamelEwsStore *store)
+{
+	g_return_if_fail (CAMEL_IS_EWS_SETTINGS (settings));
+	g_return_if_fail (CAMEL_IS_EWS_STORE (store));
+
+	if (store->priv->cnc)
+		e_ews_connection_set_timeout (store->priv->cnc,
+			camel_ews_settings_get_timeout (settings));
+}
+
 static void
 ews_store_authenticate (EEwsConnection *cnc,
                         SoupMessage *msg,
@@ -287,11 +283,12 @@ ews_connect_sync (CamelService *service,
 		return TRUE;
 
 	priv->cnc = e_ews_connection_new (hosturl, user, NULL,
+					  camel_network_settings_get_auth_mechanism (network_settings),
+					  camel_ews_settings_get_timeout (ews_settings),
 					  G_CALLBACK (ews_store_authenticate), service,
 					  error);
 
 	if (!priv->cnc) {
-		camel_service_disconnect_sync (service, TRUE, cancellable, NULL);
 		return FALSE;
 	}
 
@@ -303,10 +300,11 @@ ews_connect_sync (CamelService *service,
 	if (!success) {
 		g_object_unref (priv->cnc);
 		priv->cnc = NULL;
-		camel_service_disconnect_sync (service, TRUE, cancellable, NULL);
 		return FALSE;
 	}
 
+	g_signal_connect (ews_settings, "notify::timeout", G_CALLBACK (ews_store_update_cnc_timeout_cb), service);
+
 	camel_offline_store_set_online_sync (
 		CAMEL_OFFLINE_STORE (ews_store), TRUE, cancellable, NULL);
 
@@ -322,17 +320,16 @@ ews_disconnect_sync (CamelService *service,
 	CamelEwsStore *ews_store = (CamelEwsStore *) service;
 	CamelServiceClass *service_class;
 
-	service_class = CAMEL_SERVICE_CLASS (camel_ews_store_parent_class);
-	if (!service_class->disconnect_sync (service, clean, cancellable, error))
-		return FALSE;
-
 	/* TODO cancel all operations in the connection */
 	if (ews_store->priv->cnc) {
+		g_signal_handlers_disconnect_by_data (camel_service_get_settings (service), service);
+		e_ews_connection_forget_password (ews_store->priv->cnc);
 		g_object_unref (ews_store->priv->cnc);
 		ews_store->priv->cnc = NULL;
 	}
 
-	return TRUE;
+	service_class = CAMEL_SERVICE_CLASS (camel_ews_store_parent_class);
+	return service_class->disconnect_sync (service, clean, cancellable, error);
 }
 
 typedef struct {
@@ -424,8 +421,9 @@ ews_authenticate_sync (CamelService *service,
 			ews_store, sync_state, includes_last_folder,
 			folders_created, folders_deleted, folders_updated);
 	} else {
+		g_free (sync_state);
+
 		/* Make sure we're not leaking anything. */
-		g_warn_if_fail (sync_state == NULL);
 		g_warn_if_fail (folders_created == NULL);
 		g_warn_if_fail (folders_updated == NULL);
 		g_warn_if_fail (folders_deleted == NULL);
@@ -470,9 +468,11 @@ ews_authenticate_sync (CamelService *service,
 		result = CAMEL_AUTHENTICATION_ACCEPTED;
 	} else if (g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_AUTHENTICATION_FAILED)) {
 		g_clear_error (&local_error);
+		e_ews_connection_forget_password (priv->cnc);
 		result = CAMEL_AUTHENTICATION_REJECTED;
 	} else {
 		g_propagate_error (error, local_error);
+		e_ews_connection_forget_password (priv->cnc);
 		result = CAMEL_AUTHENTICATION_ERROR;
 	}
 
@@ -484,11 +484,9 @@ ews_store_query_auth_types_sync (CamelService *service,
                                  GCancellable *cancellable,
                                  GError **error)
 {
-	GList *auth_types = NULL;
+	g_set_error_literal (error, CAMEL_ERROR, CAMEL_ERROR_GENERIC, _("Query for authentication types is not supported"));
 
-	d(printf("in query auth types\n"));
-	auth_types = g_list_prepend (auth_types,  &camel_ews_password_authtype);
-	return auth_types;
+	return NULL;
 }
 
 static CamelFolderInfo * ews_create_folder_sync (CamelStore *store, const gchar *parent_name,const gchar *folder_name, GCancellable *cancellable, GError **error);
@@ -613,6 +611,8 @@ ews_folder_hierarchy_ready_cb (GObject *obj,
 	if (error != NULL) {
 		g_warning ("Unable to fetch the folder hierarchy: %s :%d \n", error->message, error->code);
 
+		camel_ews_store_maybe_disconnect (ews_store, error);
+
 		g_mutex_lock (priv->get_finfo_lock);
 		ews_store->priv->last_refresh_time -= FINFO_REFRESH_INTERVAL;
 		g_mutex_unlock (priv->get_finfo_lock);
@@ -666,6 +666,7 @@ ews_get_folder_info_sync (CamelStore *store,
 	GSList *folders_created = NULL, *folders_updated = NULL;
 	GSList *folders_deleted = NULL;
 	gboolean includes_last_folder;
+	GError *local_error = NULL;
 
 	ews_store = (CamelEwsStore *) store;
 	priv = ews_store->priv;
@@ -696,13 +697,16 @@ ews_get_folder_info_sync (CamelStore *store,
 			ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
 			&sync_state, &includes_last_folder,
 			&folders_created, &folders_updated,
-			&folders_deleted, cancellable, error)) {
-		if (error)
+			&folders_deleted, cancellable, &local_error)) {
+		if (local_error)
 			g_warning ("Unable to fetch the folder hierarchy: %s :%d \n",
-				   (*error)->message, (*error)->code);
+				   local_error->message, local_error->code);
 		else
 			g_warning ("Unable to fetch the folder hierarchy.\n");
 
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
+
 		g_mutex_unlock (priv->get_finfo_lock);
 		return NULL;
 	}
@@ -728,6 +732,7 @@ ews_create_folder_sync (CamelStore *store,
 	gchar *full_name;
 	EwsFolderId *folder_id;
 	CamelFolderInfo *fi = NULL;
+	GError *local_error = NULL;
 
 	/* Get Parent folder ID */
 	if (parent_name && parent_name[0]) {
@@ -740,9 +745,7 @@ ews_create_folder_sync (CamelStore *store,
 		}
 	}
 
-	if (!ews_store->priv->cnc) {
-		g_set_error (error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			     _("Cant perform actions on the folder while in offline mode"));
+	if (!camel_ews_store_connected (ews_store, error)) {
 		if (fid) g_free (fid);
 		return NULL;
 	}
@@ -752,7 +755,9 @@ ews_create_folder_sync (CamelStore *store,
 			ews_store->priv->cnc,
 			EWS_PRIORITY_MEDIUM, fid,
 			FALSE, folder_name, &folder_id,
-			cancellable, error)) {
+			cancellable, &local_error)) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		g_free (fid);
 		return NULL;
 	}
@@ -788,6 +793,7 @@ ews_delete_folder_sync (CamelStore *store,
 	CamelEwsStoreSummary *ews_summary = ews_store->summary;
 	gchar *fid;
 	CamelFolderInfo *fi = NULL;
+	GError *local_error = NULL;
 
 	fid = camel_ews_store_summary_get_folder_id_from_name (ews_summary,
 							       folder_name);
@@ -797,9 +803,7 @@ ews_delete_folder_sync (CamelStore *store,
 		return FALSE;
 	}
 
-	if (!ews_store->priv->cnc) {
-		g_set_error (error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			     _("Cant perform actions on the folder while in offline mode"));
+	if (!camel_ews_store_connected (ews_store, error)) {
 		g_free (fid);
 		return FALSE;
 	}
@@ -808,7 +812,9 @@ ews_delete_folder_sync (CamelStore *store,
 			ews_store->priv->cnc,
 			EWS_PRIORITY_MEDIUM,
 			fid, FALSE, "HardDelete",
-			cancellable, error)) {
+			cancellable, &local_error)) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
 		g_free (fid);
 		return FALSE;
 	}
@@ -864,13 +870,12 @@ ews_rename_folder_sync (CamelStore *store,
 	gchar *fid;
 	gchar *changekey;
 	gboolean res = FALSE;
+	GError *local_error = NULL;
 
 	if (!strcmp (old_name, new_name))
 		return TRUE;
 
-	if (!ews_store->priv->cnc) {
-		g_set_error (error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			     _("Cant perform actions on the folder while in offline mode"));
+	if (!camel_ews_store_connected (ews_store, error)) {
 		return FALSE;
 	}
 
@@ -938,7 +943,7 @@ ews_rename_folder_sync (CamelStore *store,
 
 		if (!e_ews_connection_update_folder_sync (
 				ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
-				rename_folder_cb, rename_data, cancellable, error)) {
+				rename_folder_cb, rename_data, cancellable, &local_error)) {
 			g_free (rename_data);
 			goto out;
 		}
@@ -965,7 +970,7 @@ ews_rename_folder_sync (CamelStore *store,
 		}
 		if (!e_ews_connection_move_folder_sync (
 				ews_store->priv->cnc, EWS_PRIORITY_MEDIUM,
-				pfid, fid, cancellable, error)) {
+				pfid, fid, cancellable, &local_error)) {
 			g_free (pfid);
 			goto out;
 		}
@@ -975,6 +980,11 @@ ews_rename_folder_sync (CamelStore *store,
 
 	res = TRUE;
  out:
+	if (local_error) {
+		camel_ews_store_maybe_disconnect (ews_store, local_error);
+		g_propagate_error (error, local_error);
+	}
+
 	g_free (changekey);
 	g_free (fid);
 	return res;
@@ -1010,8 +1020,8 @@ camel_ews_store_get_connection (CamelEwsStore *ews_store)
 
 static CamelFolder *
 ews_get_folder_by_type_sync (CamelStore *store,
-			     guint32 folder_type,
-			     GCancellable *cancellable,
+                             guint32 folder_type,
+                             GCancellable *cancellable,
                              GError **error)
 {
 	CamelEwsStore *ews_store;
@@ -1084,6 +1094,27 @@ camel_ews_store_connected (CamelEwsStore *ews_store,
 	return TRUE;
 }
 
+void
+camel_ews_store_maybe_disconnect (CamelEwsStore *store,
+				  const GError *error)
+{
+	CamelService *service;
+
+	g_return_if_fail (store != NULL);
+
+	if (!error)
+		return;
+
+	service = CAMEL_SERVICE (store);
+
+	if (camel_service_get_connection_status (service) != CAMEL_SERVICE_CONNECTED)
+		return;
+
+	if (g_error_matches (error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_NORESPONSE) ||
+	    g_error_matches (error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_AUTHENTICATION_FAILED))
+		camel_service_disconnect_sync (service, FALSE, NULL, NULL);
+}
+
 static void
 ews_store_dispose (GObject *object)
 {
@@ -1142,8 +1173,6 @@ camel_ews_store_class_init (CamelEwsStoreClass *class)
 	service_class->authenticate_sync = ews_authenticate_sync;
 
 	store_class = CAMEL_STORE_CLASS (class);
-	store_class->hash_folder_name = ews_hash_folder_name;
-	store_class->compare_folder_name = ews_compare_folder_name;
 	store_class->get_folder_sync = ews_get_folder_sync;
 	store_class->create_folder_sync = ews_create_folder_sync;
 	store_class->delete_folder_sync = ews_delete_folder_sync;
