@@ -161,7 +161,10 @@ mail_config_ews_oal_combo_box_try_password_sync (ESourceAuthenticator *auth,
 
 	/* XXX This takes a GError but never fails, so skip it. */
 	cnc = e_ews_connection_new (
-		oab_url, user, password->str, NULL, NULL, NULL);
+		oab_url, user, password->str,
+		camel_network_settings_get_auth_mechanism (network_settings),
+		camel_ews_settings_get_timeout (ews_settings),
+		NULL, NULL, NULL);
 
 	e_ews_connection_get_oal_list_sync (
 		cnc, &oal_items, cancellable, &local_error);
