@@ -62,9 +62,12 @@ enum {
 	EWS_PRIORITY_HIGH
 };
 
-typedef void (*EEwsRequestCreationCallback) (ESoapMessage *msg,
-					     gpointer user_data);
-typedef void (*EwsProgressFn) (gpointer object, gint percent);
+typedef void	(*EEwsRequestCreationCallback)	(ESoapMessage *msg,
+						 gpointer user_data);
+typedef void	(*EwsProgressFn)		(gpointer object,
+						 gint percent);
+typedef void	(*EEwsResponseCallback)		(ESoapResponse *response,
+						 GSimpleAsyncResult *simple);
 
 typedef enum {
 	EWS_SEARCH_AD,
@@ -187,9 +190,18 @@ GType		e_ews_connection_get_type	(void);
 EEwsConnection *e_ews_connection_new		(const gchar *uri,
 						 const gchar *username,
 						 const gchar *password,
+						 const gchar *auth_mechanism,
+						 guint timeout,
 						 GCallback authenticate_cb,
 						 gpointer authenticate_ctx,
 						 GError **error);
+const gchar *	e_ews_connection_get_uri	(EEwsConnection *cnc);
+SoupSession *	e_ews_connection_ref_soup_session
+						(EEwsConnection *cnc);
+void		e_ews_connection_forget_password
+						(EEwsConnection *cnc);
+void		e_ews_connection_set_timeout	(EEwsConnection *cnc,
+						 guint timeout);
 EEwsConnection *e_ews_connection_find		(const gchar *uri,
 						 const gchar *username);
 void		e_ews_connection_authenticate	(EEwsConnection *cnc,
@@ -197,6 +209,12 @@ void		e_ews_connection_authenticate	(EEwsConnection *cnc,
 						 const gchar *user,
 						 const gchar *passwd,
 						 GError *error);
+void		e_ews_connection_queue_request	(EEwsConnection *cnc,
+						 ESoapMessage *msg,
+						 EEwsResponseCallback cb,
+						 gint pri,
+						 GCancellable *cancellable,
+						 GSimpleAsyncResult *simple);
 
 gboolean	e_ews_autodiscover_ws_url_sync	(CamelEwsSettings *settings,
 						 const gchar *email_address,
@@ -213,6 +231,7 @@ gboolean	e_ews_autodiscover_ws_url_finish
 						(CamelEwsSettings *settings,
 						 GAsyncResult *result,
 						 GError **error);
+const gchar *	e_ews_connection_get_mailbox	(EEwsConnection *cnc);
 void		e_ews_connection_set_mailbox	(EEwsConnection *cnc,
 						 const gchar *email);
 
@@ -497,6 +516,15 @@ gboolean	e_ews_connection_expand_dl_sync	(EEwsConnection *cnc,
 						 GCancellable *cancellable,
 						 GError **error);
 
+gboolean	e_ews_connection_ex_to_smtp_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *name,
+						 const gchar *ex_address,
+						 gchar **smtp_address,
+						 GCancellable *cancellable,
+						 GError **error);
+
 void		e_ews_connection_create_folder	(EEwsConnection *cnc,
 						 gint pri,
 						 const gchar *parent_folder_id,
