@@ -39,8 +39,10 @@ ESoapMessage *	e_ews_message_new_with_header	(const gchar *uri,
 						 const gchar *attribute_value,
 						 EwsServerVersion version);
 void		e_ews_message_write_string_parameter
-						(ESoapMessage *msg, const gchar *name,
-						 const gchar *prefix, const gchar *value);
+						(ESoapMessage *msg,
+						 const gchar *name,
+						 const gchar *prefix,
+						 const gchar *value);
 void		e_ews_message_write_string_parameter_with_attribute
 						(ESoapMessage *msg,
 						 const gchar *name,
@@ -58,7 +60,6 @@ void		e_ews_message_write_int_parameter
 						 const gchar *name,
 						 const gchar *prefix,
 						 glong value);
-
 void		e_ews_message_write_footer	(ESoapMessage *msg);
 
 G_END_DECLS
