@@ -321,3 +321,67 @@ ews_get_error_code (const gchar *str)
 
 	return error_code;
 }
+
+gboolean
+ews_get_response_status (ESoapParameter *param,
+                         GError **error)
+{
+	ESoapParameter *subparam;
+	gchar *value;
+	gchar *message_text;
+	gchar *response_code;
+	gint error_code;
+	gboolean success = TRUE;
+
+	value = e_soap_parameter_get_property (param, "ResponseClass");
+	g_return_val_if_fail (value != NULL, FALSE);
+
+	if (g_ascii_strcasecmp (value, "Error") != 0)
+		goto exit;
+
+	subparam = e_soap_parameter_get_first_child_by_name (param, "MessageText");
+	message_text = e_soap_parameter_get_string_value (subparam);
+
+	subparam = e_soap_parameter_get_first_child_by_name (param, "ResponseCode");
+	response_code = e_soap_parameter_get_string_value (subparam);
+	error_code = ews_get_error_code (response_code);
+
+	switch (error_code) {
+		case EWS_CONNECTION_ERROR_CORRUPTDATA:
+			/* FIXME: This happens because of a bug in the
+			 * Exchange server, which doesn't like returning
+			 * <Recurrence> for any appointment without a
+			 * timezone, even if it's an all day event like a
+			 * birthday. We need to handle the error and
+			 * correctly report it to the user, but for now
+			 * we'll just ignore it... */
+			break;
+
+		case EWS_CONNECTION_ERROR_INVALIDPROPERTYREQUEST:
+			/* Ick, another one. If we try to set the IsRead
+			 * flag on certain types of item (task requests,
+			 * those stupid 'recall' requests), it complains.
+			 * We really need to find a better way to return
+			 * individual errors for each response to a multiple
+			 * request; it isn't necessarily the case that a
+			 * single error should be reported as an error for
+			 * the whole transaction */
+			break;
+
+		default:
+			g_set_error (
+				error, EWS_CONNECTION_ERROR,
+				error_code, "%s", message_text);
+			success = FALSE;
+			break;
+	}
+
+	g_free (message_text);
+	g_free (response_code);
+
+exit:
+	g_free (value);
+
+	return success;
+}
+
