@@ -58,9 +58,7 @@ resolve_names_cb (GObject *object,
 			EwsMailbox *mb = (EwsMailbox *) l->data;
 			g_print ("%s:%s \n", mb->name, mb->email);
 
-			g_free (mb->name);
-			g_free (mb->email);
-			g_free (mb);
+			e_ews_mailbox_free (mb);
 		}
 
 		g_slist_free (mailboxes);
@@ -90,7 +88,7 @@ op_test_resolve_names ()
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, NULL, NULL);
+	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
 	g_assert (cnc != NULL);
 	e_ews_connection_resolve_names (
 		cnc, EWS_PRIORITY_MEDIUM, username,
