@@ -76,7 +76,7 @@ op_test_delete_folder (gpointer data)
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, NULL, NULL);
+	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
 	g_assert (cnc != NULL);
 	e_ews_connection_delete_folder (
 		cnc, EWS_PRIORITY_MEDIUM, (*fid)->id,
